<?php

/*

Plugin Name: Custom Thank You Page
Plugin URI: https://www.themeinprogress.com/custom-thank-you-page-for-woocommerce/
Description: Custom Thank You Page allows you to customize the final thank you page of WooCommerce.
Version: 1.1.0
Text Domain: custom-thank-you-page
Author: ThemeinProgress
Author URI: https://www.themeinprogress.com
License: GPL3
Domain Path: /languages/

Copyright 2024  ThemeinProgress  (email : support@wpinprogress.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

WC requires at least: 3.0.0
WC tested up to: 8.5

*/

define( 'CTYP_NAME', 'Custom Thank You Page' );
define( 'CTYP_VERSION', '1.1.0' );
define( 'CTYP_DEMO_URL', 'https://custom-thank-you-page-pro.demo.themeinprogress.com/' );
define( 'CTYP_UPGRADE_LINK', 'https://www.themeinprogress.com/custom-thank-you-page-for-woocommerce' );
define( 'CTYP_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );

if( !class_exists( 'ctyp_init' ) ) {

	class ctyp_init {

		/**
		* Constructor
		*/

		public function __construct() {

			add_action('admin_init', array(&$this, 'disable_plugins'));
			add_action('plugins_loaded', array(&$this,'plugin_setup'));
			add_filter('plugin_action_links_' . plugin_basename(__FILE__), array( $this, 'plugin_action_links' ), 10, 2 );

		}

		/**
		* Disable Plugins
		*/

		public function disable_plugins() {

			if (is_plugin_active('custom-thank-you-page-pro/init.php'))
				deactivate_plugins('custom-thank-you-page-pro/init.php');

			if (!is_plugin_active('woocommerce/woocommerce.php'))
				deactivate_plugins('custom-thank-you-page/init.php');

		}

		/**
		* Plugin settings link
		*/

		public function plugin_action_links( $links ) {

			$links[] = '<a href="'. esc_url( get_admin_url(null, 'admin.php?page=ctyp_panel') ) .'">' . esc_html__('Settings', 'custom-thank-you-page') . '</a>';
			$links[] = '<a target="_blank" href="'. esc_url( CTYP_UPGRADE_LINK . '/?ref=2&campaign=plugin_section' ).'">' . esc_html__('Upgrade to Premium', 'custom-thank-you-page') . '</a>';
			return $links;

		}

		/**
		* Plugin setup
		*/

		public function plugin_setup() {

			load_plugin_textdomain( 'custom-thank-you-page', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/');

			require_once dirname(__FILE__) . '/core/functions/functions.php';
			require_once dirname(__FILE__) . '/core/includes/class-ecommerce.php';
			require_once dirname(__FILE__) . '/core/includes/class-form.php';
			require_once dirname(__FILE__) . '/core/includes/class-panel.php';
			require_once dirname(__FILE__) . '/core/includes/class-notice.php';

			new ctyp_ecommerce();

			if ( is_admin() == 1 )
				require_once dirname(__FILE__) . '/core/admin/panel.php';

		}

	}

	new ctyp_init();

}

?>
